
# StarSearch
[![License](https://img.shields.io/badge/license-MIT-blue.svg)](https://github.com/jdavidrcamacho/tedi/blob/master/LICENSE)

This small package allows you to search for phase 3 spectra on the ESO archive

You can install the stable version with pip:

        $ pip install starsearch

Or download the unstable version's repository and in the terminal type:

        $ python setup.py develop

Check the [wiki page](https://github.com/jdavidrcamacho/StarSearch/wiki) to learn how to use it!


### To do list

- [x] Download spectra considering a given instrument
- [x] Download spectra considering a given date
- [x] Download spectra considering a given SNR
- [x] Test everything
- [x] Download spectra from a list of stars
- [x] Copy astroquery eso files 
- [x] Adapt astroquery files to work on StarSearch
- [x] Test everything
- [x] Prepare examples on how to use it
- [x] Upload it to pypi
- [x] Summary of spectra found on arquive
- [ ] Comparison of two diferent spectra parameters
- [ ] Test everything

----------
<img align="right" width="180" height="180" src="https://i.imgur.com/yhIts2Y.png">
